function gameStart()
    math.randomseed(os.time())
    love.graphics.setBackgroundColor(0, 0, 0)

    initGlobals()

    love.physics.setMeter(32)
    love.graphics.setDefaultFilter("nearest", "nearest")

    fullscreen = false
    testWindow = false
    vertical = false
    setWindowSize(fullscreen, 1920, 1080)

    if vertical then
        fullscreen = false
        testWindow = true
        setWindowSize(fullscreen, 1360, 1920)
    end

    setScale()

    vector = require "libraries.hump.vector"
    flux = require "libraries.flux"
    require("libraries.tesound")
    require('libraries.show')

    anim8 = require("libraries.anim8")
    sti = require("libraries.sti")
    Camera = require "libraries.hump.camera"

    local windfield = require("libraries.windfield")
    world = windfield.newWorld(0, 0, false)

    Shadows = require("shadows")
    LightWorld = require("shadows.LightWorld")
    Light = require("shadows.Light")
    Body = require("shadows.Body")
    PolygonShadow = require("shadows.ShadowShapes.PolygonShadow")
    CircleShadow = require("shadows.ShadowShapes.CircleShadow")
    Transform = require("shadows.Transform")

    lightWorld = LightWorld:new()

    require("src.require")
    requireAll()

    camera = Camera(0, 0)

    loadMap("test")
end

function setWindowSize(full, width, height)
    if full then
        fullscreen = true
        love.window.setFullscreen(true)
        windowWidth = love.graphics.getWidth()
        windowHeight = love.graphics.getHeight()
    else
        fullscreen = false
        if width == nil or height == nil then
            windowWidth = 1920
            windowHeight = 1080
        else
            windowWidth = width
            windowHeight = height
        end
        love.window.setMode( windowWidth, windowHeight, {resizable = not testWindow} )
    end
end


function initGlobals()
    data = {} -- save data, will be loaded after game begins

    -- game state
    -- 0: main menu
    -- 1: gameplay
    gamestate = 1
    globalStun = 0
end

function setScale()
    scale = 2

    if cam then
        cam:zoomTo(scale)
    end
end

function checkWindowSize()
    local width = love.graphics.getWidth()
    local height = love.graphics.getHeight()
    if width ~= windowWidth or height ~= windowHeight then
        reinitSize()
    end
end


function reinitSize()
    -- Reinitialize everything
    windowWidth = love.graphics.getWidth()
    windowHeight = love.graphics.getHeight()
end